@@ -1,28 +1,367 @@
 use strict;
 use warnings;
 package Getopt::Long::Descriptive;
+{
+  $Getopt::Long::Descriptive::VERSION = '0.092';
+}
+# ABSTRACT: Getopt::Long, but simpler and more powerful
 
 use Carp qw(carp croak);
 use File::Basename ();
 use Getopt::Long 2.33;
 use List::Util qw(first);
-use Params::Validate qw(:all);
+use Params::Validate 0.97 qw(:all);
 use Scalar::Util ();
 
 use Getopt::Long::Descriptive::Opts;
 use Getopt::Long::Descriptive::Usage;
 
+
+my $prog_name;
+sub prog_name { @_ ? ($prog_name = shift) : $prog_name }
+
+BEGIN {
+  # grab this before someone decides to change it
+  prog_name(File::Basename::basename($0));
+}
+
+use Sub::Exporter::Util ();
+use Sub::Exporter 0.972 -setup => {
+  exports => [
+    describe_options => \'_build_describe_options',
+    q(prog_name),
+    @{ $Params::Validate::EXPORT_TAGS{types} }
+  ],
+  groups  => [
+    default => [ qw(describe_options) ],
+    types   => $Params::Validate::EXPORT_TAGS{types},
+  ],
+};
+
+my %CONSTRAINT = (
+  implies  => \&_mk_implies,
+  required => { optional => 0 },
+  only_one => \&_mk_only_one,
+);
+
+our $MungeOptions = 1;
+
+sub _nohidden {
+  return grep { ! $_->{constraint}->{hidden} } @_;
+}
+
+sub _expand {
+  return map { {(
+    spec       => $_->[0] || '',
+    desc       => @$_ > 1 ? $_->[1] : 'spacer',
+    constraint => $_->[2] || {},
+
+    # if @$_ is 0 then we got [], a spacer
+    name       => @$_ ? _munge((split /[:=|!+]/, $_->[0] || '')[0]) : '',
+  )} } @_;
+}
+
+my %HIDDEN = (
+  hidden => 1,
+);
+
+my $SPEC_RE = qr{(?:[:=][\d\w\+]+[%@]?({\d*,\d*})?|[!+])$};
+sub _strip_assignment {
+  my ($self, $str) = @_;
+
+  (my $copy = $str) =~ s{$SPEC_RE}{};
+
+  return $copy;
+}
+
+# This is here only to deal with people who were calling this fully-qualified
+# without importing.  Sucks to them!  -- rjbs, 2009-08-21
+sub describe_options {
+  my $sub = __PACKAGE__->_build_describe_options(describe_options => {} => {});
+  $sub->(@_);
+}
+
+sub usage_class { 'Getopt::Long::Descriptive::Usage' }
+
+sub _build_describe_options {
+  my ($class) = @_;
+
+  sub {
+    my $format = shift;
+    my $arg    = (ref $_[-1] and ref $_[-1] eq 'HASH') ? pop @_ : {};
+    my @opts;
+
+    # special casing
+    # wish we had real loop objects
+    my %method_map;
+    for my $opt (_expand(@_)) {
+      $method_map{ $opt->{name} } = undef unless $opt->{desc} eq 'spacer';
+
+      if (ref($opt->{desc}) eq 'ARRAY') {
+        $opt->{constraint}->{one_of} = delete $opt->{desc};
+        $opt->{desc} = 'hidden';
+      }
+      if ($HIDDEN{$opt->{desc}}) {
+        $opt->{constraint}->{hidden}++;
+      }
+      if ($opt->{constraint}->{one_of}) {
+        for my $one_opt (_expand(
+          @{delete $opt->{constraint}->{one_of}}
+        )) {
+          $one_opt->{constraint}->{implies}
+            ->{$opt->{name}} = $one_opt->{name};
+          for my $wipe (qw(required default)) {
+            if ($one_opt->{constraint}->{$wipe}) {
+              carp "'$wipe' constraint does not make sense in sub-option";
+              delete $one_opt->{constraint}->{$wipe};
+            }
+          }
+          $one_opt->{constraint}->{one_of} = $opt->{name};
+          push @opts, $one_opt;
+        }
+      }
+      push @opts, $opt;
+    }
+
+    my @go_conf = @{ $arg->{getopt_conf} || $arg->{getopt} || [] };
+    if ($arg->{getopt}) {
+      warn "describe_options: 'getopt' is deprecated, please use 'getopt_conf' instead\n";
+    }
+
+    push @go_conf, "bundling" unless grep { /bundling/i } @go_conf;
+    push @go_conf, "no_auto_help"  unless grep { /no_auto_help/i } @go_conf;
+
+    # not entirely sure that all of this (until the Usage->new) shouldn't be
+    # moved into Usage -- rjbs, 2009-08-19
+
+    # all specs including hidden
+    my @getopt_specs =
+      map  { $_->{spec} }
+      grep { $_->{desc} ne 'spacer' }
+      @opts;
+
+    my @specs =
+      map  { $_->{spec} }
+      grep { $_->{desc} ne 'spacer' }
+      _nohidden(@opts);
+
+    my $short = join q{},
+      sort  { lc $a cmp lc $b or $a cmp $b }
+      grep  { /^.$/ }
+      map   { split /\|/ }
+      map   { __PACKAGE__->_strip_assignment($_) }
+      @specs;
+
+    my $long = grep /\b[^|]{2,}/, @specs;
+
+    my %replace = (
+      "%" => "%",
+      "c" => prog_name,
+      "o" => join(q{ },
+        ($short ? "[-$short]" : ()),
+        ($long  ? "[long options...]" : ())
+      ),
+    );
+
+    (my $str = $format) =~ s/%(.)/$replace{$1}/ge;
+    $str =~ s/\s{2,}/ /g;
+
+    my $usage = $class->usage_class->new({
+      options     => [ _nohidden(@opts) ],
+      leader_text => $str,
+    });
+
+    Getopt::Long::Configure(@go_conf);
+
+    my %return;
+    $usage->die unless GetOptions(\%return, grep { length } @getopt_specs);
+    my @given_keys = keys %return;
+
+    for my $opt (keys %return) {
+      my $newopt = _munge($opt);
+      next if $newopt eq $opt;
+      $return{$newopt} = delete $return{$opt};
+    }
+
+    for my $copt (grep { $_->{constraint} } @opts) {
+      delete $copt->{constraint}->{hidden};
+      my $name = $copt->{name};
+      my $new  = _validate_with(
+        name   => $name,
+        params => \%return,
+        spec   => $copt->{constraint},
+        opts   => \@opts,
+        usage  => $usage,
+      );
+      next unless (defined($new) || exists($return{$name}));
+      $return{$name} = $new;
+    }
+
+    my $opt_obj = Getopt::Long::Descriptive::Opts->___new_opt_obj({
+      values => { %method_map, %return },
+      given  => { map {; $_ => 1 } @given_keys },
+    });
+
+    return($opt_obj, $usage);
+  }
+}
+
+sub _munge {
+  my ($opt) = @_;
+  return $opt unless $MungeOptions;
+  $opt = lc($opt);
+  $opt =~ tr/-/_/;
+  return $opt;
+}
+
+sub _validate_with {
+  my (%arg) = validate(@_, {
+    name   => 1,
+    params => 1,
+    spec   => 1,
+    opts   => 1,
+    usage  => 1,
+  });
+  my $spec = $arg{spec};
+  my %pvspec;
+  for my $ct (keys %{$spec}) {
+    if ($CONSTRAINT{$ct} and ref $CONSTRAINT{$ct} eq 'CODE') {
+      $pvspec{callbacks} ||= {};
+      $pvspec{callbacks} = {
+        %{$pvspec{callbacks}},
+        $CONSTRAINT{$ct}->(
+          $arg{name},
+          $spec->{$ct},
+          $arg{params},
+          $arg{opts},
+        ),
+      };
+    } else {
+      %pvspec = (
+        %pvspec,
+        $CONSTRAINT{$ct} ? %{$CONSTRAINT{$ct}} : ($ct => $spec->{$ct}),
+      );
+    }
+  }
+
+  $pvspec{optional} = 1 unless exists $pvspec{optional};
+
+  # we need to implement 'default' by ourselves sometimes
+  # because otherwise the implies won't be checked/executed
+  # XXX this should be more generic -- we'll probably want
+  # other callbacks to always run, too
+  if (!defined($arg{params}{$arg{name}})
+        && $pvspec{default}
+          && $spec->{implies}) {
+
+    $arg{params}{$arg{name}} = delete $pvspec{default};
+  }
+
+  my %p;
+  my $ok = eval {
+    %p = validate_with(
+      params => [ %{$arg{params}} ],
+      spec   => { $arg{name} => \%pvspec },
+      allow_extra => 1,
+      on_fail     => sub {
+        my $fail_msg = shift;
+        Getopt::Long::Descriptive::_PV_Error->throw($fail_msg);
+      },
+    );
+    1;
+  };
+
+  if (! $ok) {
+    my $error = $@;
+    if (
+      Scalar::Util::blessed($error)
+      && $error->isa('Getopt::Long::Descriptive::_PV_Error')
+    ) {
+      $arg{usage}->die({ pre_text => $error->error . "\n" });
+    }
+
+    die $@;
+  }
+
+  return $p{$arg{name}};
+}
+
+# scalar:   single option = true
+# arrayref: multiple options = true
+# hashref:  single/multiple options = given values
+sub _norm_imply {
+  my ($what) = @_;
+
+  return { $what => 1 } unless my $ref = ref $what;
+
+  return $what                      if $ref eq 'HASH';
+  return { map { $_ => 1 } @$what } if $ref eq 'ARRAY';
+
+  die "can't imply: $what";
+}
+
+sub _mk_implies {
+  my $name = shift;
+  my $what = _norm_imply(shift);
+  my $param = shift;
+  my $opts  = shift;
+
+  for my $implied (keys %$what) {
+    die("option specification for $name implies nonexistent option $implied\n")
+      unless first { $_->{name} eq $implied } @$opts
+  }
+
+  my $whatstr = join(q{, }, map { "$_=$what->{$_}" } keys %$what);
+
+  return "$name implies $whatstr" => sub {
+    my ($pv_val) = shift;
+
+    # negatable options will be 0 here, which is ok.
+    return 1 unless defined $pv_val;
+
+    while (my ($key, $val) = each %$what) {
+      if (exists $param->{$key} and $param->{$key} ne $val) {
+        die(
+          "option specification for $name implies that $key should be "
+          . "set to '$val', but it is '$param->{$key}' already\n"
+        );
+      }
+      $param->{$key} = $val;
+    }
+
+    return 1;
+  };
+}
+
+sub _mk_only_one {
+  die "unimplemented";
+}
+
+{
+  package
+    Getopt::Long::Descriptive::_PV_Error;
+  sub error { $_[0]->{error} }
+  sub throw {
+    my ($class, $error_msg) = @_;
+    my $self = { error => $error_msg };
+    bless $self, $class;
+    die $self;
+  }
+}
+
+
+1; # End of Getopt::Long::Descriptive
+
+__END__
+=pod
+
 =head1 NAME
 
 Getopt::Long::Descriptive - Getopt::Long, but simpler and more powerful
 
 =head1 VERSION
 
-Version 0.089
-
-=cut
-
-our $VERSION = '0.089';
+version 0.092
 
 =head1 SYNOPSIS
 
@@ -48,7 +387,7 @@ our $VERSION = '0.089';
   my-program [-psv] [long options...] <some-arg>
     -s --server     the server to connect to
     -p --port       the port to connect to
-                  
+
     -v --verbose    print extra stuff
     --help          print usage message and exit
 
@@ -246,314 +585,6 @@ well.  You can get all of them at once by importing C<-types>.
 
 This import group will import C<-type>, C<describe_options>, and C<prog_name>.
 
-=cut
-
-my $prog_name;
-sub prog_name { @_ ? ($prog_name = shift) : $prog_name }
-
-BEGIN {
-  # grab this before someone decides to change it
-  prog_name(File::Basename::basename($0));
-}
-
-use Sub::Exporter::Util ();
-use Sub::Exporter 0.972 -setup => {
-  exports => [
-    describe_options => \'_build_describe_options',
-    q(prog_name),
-    @{ $Params::Validate::EXPORT_TAGS{types} }
-  ],
-  groups  => [
-    default => [ qw(describe_options) ],
-    types   => $Params::Validate::EXPORT_TAGS{types},
-  ],
-};
-
-my %CONSTRAINT = (
-  implies  => \&_mk_implies,
-  required => { optional => 0 },
-  only_one => \&_mk_only_one,
-);
-
-our $MungeOptions = 1;
-
-sub _nohidden {
-  return grep { ! $_->{constraint}->{hidden} } @_;
-}
-
-sub _expand {
-  return map { {(
-    spec       => $_->[0] || '',
-    desc       => @$_ > 1 ? $_->[1] : 'spacer',
-    constraint => $_->[2] || {},
-
-    # if @$_ is 0 then we got [], a spacer
-    name       => @$_ ? _munge((split /[:=|!+]/, $_->[0] || '')[0]) : '',
-  )} } @_;
-}
-    
-my %HIDDEN = (
-  hidden => 1,
-);
-
-my $SPEC_RE = qr{(?:[:=][\d\w\+]+[%@]?({\d*,\d*})?|[!+])$};
-sub _strip_assignment {
-  my ($self, $str) = @_;
-
-  (my $copy = $str) =~ s{$SPEC_RE}{};
-
-  return $copy;
-}
-
-# This is here only to deal with people who were calling this fully-qualified
-# without importing.  Sucks to them!  -- rjbs, 2009-08-21
-sub describe_options {
-  my $sub = __PACKAGE__->_build_describe_options(describe_options => {} => {});
-  $sub->(@_);
-}
-
-sub usage_class { 'Getopt::Long::Descriptive::Usage' }
-
-sub _build_describe_options {
-  my ($class) = @_;
-
-  sub {
-    my $format = shift;
-    my $arg    = (ref $_[-1] and ref $_[-1] eq 'HASH') ? pop @_ : {};
-    my @opts;
-
-    # special casing
-    # wish we had real loop objects
-    my %method_map;
-    for my $opt (_expand(@_)) {
-      $method_map{ $opt->{name} } = undef unless $opt->{desc} eq 'spacer';
- 
-      if (ref($opt->{desc}) eq 'ARRAY') {
-        $opt->{constraint}->{one_of} = delete $opt->{desc};
-        $opt->{desc} = 'hidden';
-      }
-      if ($HIDDEN{$opt->{desc}}) {
-        $opt->{constraint}->{hidden}++;
-      }
-      if ($opt->{constraint}->{one_of}) {
-        for my $one_opt (_expand(
-          @{delete $opt->{constraint}->{one_of}}
-        )) {
-          $one_opt->{constraint}->{implies}
-            ->{$opt->{name}} = $one_opt->{name};
-          for my $wipe (qw(required default)) {
-            if ($one_opt->{constraint}->{$wipe}) {
-              carp "'$wipe' constraint does not make sense in sub-option";
-              delete $one_opt->{constraint}->{$wipe};
-            }
-          }
-          $one_opt->{constraint}->{one_of} = $opt->{name};
-          push @opts, $one_opt;
-        }
-      }
-      push @opts, $opt;
-    }
-    
-    my @go_conf = @{ $arg->{getopt_conf} || $arg->{getopt} || [] };
-    if ($arg->{getopt}) {
-      warn "describe_options: 'getopt' is deprecated, please use 'getopt_conf' instead\n";
-    }
-
-    push @go_conf, "bundling" unless grep { /bundling/i } @go_conf;
-    push @go_conf, "no_auto_help"  unless grep { /no_auto_help/i } @go_conf;
-
-    # not entirely sure that all of this (until the Usage->new) shouldn't be
-    # moved into Usage -- rjbs, 2009-08-19
-    my @specs =
-      map  { $_->{spec} }
-      grep { $_->{desc} ne 'spacer' }
-      _nohidden(@opts);
-
-    my $short = join q{},
-      sort  { lc $a cmp lc $b or $a cmp $b }
-      grep  { /^.$/ }
-      map   { split /\|/ }
-      map   { __PACKAGE__->_strip_assignment($_) }
-      @specs;
-    
-    my $long = grep /\b[^|]{2,}/, @specs;
-
-    my %replace = (
-      "%" => "%",
-      "c" => prog_name,
-      "o" => join(q{ },
-        ($short ? "[-$short]" : ()),
-        ($long  ? "[long options...]" : ())
-      ),
-    );
-
-    (my $str = $format) =~ s/%(.)/$replace{$1}/ge;
-    $str =~ s/\s{2,}/ /g;
-
-    my $usage = $class->usage_class->new({
-      options     => [ _nohidden(@opts) ],
-      leader_text => $str,
-    });
-
-    Getopt::Long::Configure(@go_conf);
-
-    my %return;
-    $usage->die unless GetOptions(\%return, grep { length } @specs);
-    my @given_keys = keys %return;
-
-    for my $opt (keys %return) {
-      my $newopt = _munge($opt);
-      next if $newopt eq $opt;
-      $return{$newopt} = delete $return{$opt};
-    }
-
-    for my $copt (grep { $_->{constraint} } @opts) {
-      delete $copt->{constraint}->{hidden};
-      my $name = $copt->{name};
-      my $new  = _validate_with(
-        name   => $name,
-        params => \%return,
-        spec   => $copt->{constraint},
-        opts   => \@opts,
-        usage  => $usage,
-      );
-      next unless (defined($new) || exists($return{$name}));
-      $return{$name} = $new;
-    }
-
-    my $opt_obj = Getopt::Long::Descriptive::Opts->___new_opt_obj({
-      values => { %method_map, %return },
-      given  => { map {; $_ => 1 } @given_keys },
-    });
-
-    return($opt_obj, $usage);
-  }
-}
-
-sub _munge {
-  my ($opt) = @_;
-  return $opt unless $MungeOptions;
-  $opt = lc($opt);
-  $opt =~ tr/-/_/;
-  return $opt;
-}
-
-sub _validate_with {
-  my (%arg) = validate(@_, {
-    name   => 1,
-    params => 1,
-    spec   => 1,
-    opts   => 1,
-    usage  => 1,
-  });
-  my $spec = $arg{spec};
-  my %pvspec;
-  for my $ct (keys %{$spec}) {
-    if ($CONSTRAINT{$ct} and ref $CONSTRAINT{$ct} eq 'CODE') {
-      $pvspec{callbacks} ||= {};
-      $pvspec{callbacks} = {
-        %{$pvspec{callbacks}},
-        $CONSTRAINT{$ct}->(
-          $arg{name},
-          $spec->{$ct},
-          $arg{params},
-          $arg{opts},
-        ),
-      };
-    } else {
-      %pvspec = (
-        %pvspec,
-        $CONSTRAINT{$ct} ? %{$CONSTRAINT{$ct}} : ($ct => $spec->{$ct}),
-      );
-    }
-  }
-
-  $pvspec{optional} = 1 unless exists $pvspec{optional};
-
-  # we need to implement 'default' by ourselves sometimes
-  # because otherwise the implies won't be checked/executed
-  # XXX this should be more generic -- we'll probably want
-  # other callbacks to always run, too
-  if (!defined($arg{params}{$arg{name}})
-        && $pvspec{default}
-          && $spec->{implies}) {
-
-    $arg{params}{$arg{name}} = delete $pvspec{default};
-  }
-
-  my %p = eval { 
-    validate_with(
-      params => [ %{$arg{params}} ],
-      spec   => { $arg{name} => \%pvspec },
-      allow_extra => 1,
-    );
-  };
-
-  if ($@) {
-    if ($@ =~ /^Mandatory parameter '([^']+)' missing/) {
-      my $missing = $1;
-      $arg{usage}->die({
-        pre_text => "Required option missing: $1\n",
-      });
-    }
-
-    die $@;
-  }
-      
-  return $p{$arg{name}};
-}
-
-# scalar:   single option = true
-# arrayref: multiple options = true
-# hashref:  single/multiple options = given values
-sub _norm_imply {
-  my ($what) = @_;
-
-  return { $what => 1 } unless my $ref = ref $what;
-
-  return $what                      if $ref eq 'HASH';
-  return { map { $_ => 1 } @$what } if $ref eq 'ARRAY';
-
-  die "can't imply: $what";
-}
-
-sub _mk_implies {
-  my $name = shift;
-  my $what = _norm_imply(shift);
-  my $param = shift;
-  my $opts  = shift;
-
-  for my $implied (keys %$what) {
-    die("option specification for $name implies nonexistent option $implied\n")
-      unless first { $_->{name} eq $implied } @$opts
-  }
-
-  my $whatstr = join(q{, }, map { "$_=$what->{$_}" } keys %$what);
-
-  return "$name implies $whatstr" => sub {
-    my ($pv_val) = shift;
-
-    # negatable options will be 0 here, which is ok.
-    return 1 unless defined $pv_val;
-
-    while (my ($key, $val) = each %$what) {
-      if (exists $param->{$key} and $param->{$key} ne $val) {
-        die(
-          "option specification for $name implies that $key should be "
-          . "set to '$val', but it is '$param->{$key}' already\n"
-        );
-      }
-      $param->{$key} = $val;
-    }
-
-    return 1;
-  };
-}
-
-sub _mk_only_one {
-  die "unimplemented";
-}
-
 =head1 CUSTOMIZING
 
 Getopt::Long::Descriptive uses L<Sub::Exporter|Sub::Exporter> to build and
@@ -572,30 +603,38 @@ to Getopt::Long::Descriptive::Usage.
 
 =head1 SEE ALSO
 
+=over 4
+
+=item *
+
 L<Getopt::Long>
+
+=item *
+
 L<Params::Validate>
 
+=back
+
 =head1 AUTHORS
 
-Hans Dieter Pearcey, C<< <hdp@cpan.org> >>
+=over 4
 
-Ricardo Signes, C<< <rjbs@cpan.org> >>
+=item *
 
-=head1 BUGS
+Hans Dieter Pearcey <hdp@cpan.org>
 
-Please report any bugs or feature requests to
-C<bug-getopt-long-descriptive@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Getopt-Long-Descriptive>.
-I will be notified, and then you'll automatically be notified of progress on
-your bug as I make changes.
+=item *
 
-=head1 COPYRIGHT & LICENSE
+Ricardo Signes <rjbs@cpan.org>
 
-Copyright 2005 Hans Dieter Pearcey, all rights reserved.
+=back
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2005 by Hans Dieter Pearcey.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1; # End of Getopt::Long::Descriptive
